@@ -19,25 +19,27 @@ package main
 import (
 	"flag"
 	"fmt"
-	"io/ioutil"
 	"os"
 
+	coordinationv1 "k8s.io/api/coordination/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/apimachinery/pkg/types"
 	_ "k8s.io/client-go/plugin/pkg/client/auth/gcp"
 	"k8s.io/klog/v2"
 	"k8s.io/klog/v2/klogr"
 	"k8s.io/kops/cmd/kops-controller/controllers"
 	"k8s.io/kops/cmd/kops-controller/pkg/config"
 	"k8s.io/kops/cmd/kops-controller/pkg/server"
+	"k8s.io/kops/pkg/bootstrap"
 	"k8s.io/kops/pkg/nodeidentity"
 	nodeidentityaws "k8s.io/kops/pkg/nodeidentity/aws"
 	nodeidentityazure "k8s.io/kops/pkg/nodeidentity/azure"
 	nodeidentitydo "k8s.io/kops/pkg/nodeidentity/do"
 	nodeidentitygce "k8s.io/kops/pkg/nodeidentity/gce"
 	nodeidentityos "k8s.io/kops/pkg/nodeidentity/openstack"
-	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
+	"k8s.io/kops/upup/pkg/fi/cloudup/gce/tpm/gcetpmverifier"
 	ctrl "sigs.k8s.io/controller-runtime"
 	"sigs.k8s.io/controller-runtime/pkg/manager"
 	"sigs.k8s.io/yaml"
@@ -73,7 +75,7 @@ func main() {
 	opt.PopulateDefaults()
 
 	{
-		b, err := ioutil.ReadFile(configPath)
+		b, err := os.ReadFile(configPath)
 		if err != nil {
 			klog.Fatalf("failed to read configuration file %q: %v", configPath, err)
 		}
@@ -85,7 +87,7 @@ func main() {
 
 	ctrl.SetLogger(klogr.New())
 	if opt.Server != nil {
-		var verifier fi.Verifier
+		var verifier bootstrap.Verifier
 		var err error
 		if opt.Server.Provider.AWS != nil {
 			verifier, err = awsup.NewAWSVerifier(opt.Server.Provider.AWS)
@@ -93,6 +95,12 @@ func main() {
 				setupLog.Error(err, "unable to create verifier")
 				os.Exit(1)
 			}
+		} else if opt.Server.Provider.GCE != nil {
+			verifier, err = gcetpmverifier.NewTPMVerifier(opt.Server.Provider.GCE)
+			if err != nil {
+				setupLog.Error(err, "unable to create verifier")
+				os.Exit(1)
+			}
 		} else {
 			klog.Fatalf("server cloud provider config not provided")
 		}
@@ -125,10 +133,33 @@ func main() {
 		os.Exit(1)
 	}
 
+	if opt.EnableCloudIPAM {
+		setupLog.Info("enabling IPAM controller")
+		if opt.Cloud != "aws" {
+			klog.Error("IPAM controller only supported by aws")
+			os.Exit(1)
+		}
+		ipamController, err := controllers.NewAWSIPAMReconciler(mgr)
+		if err != nil {
+			setupLog.Error(err, "unable to create controller", "controller", "IPAMController")
+			os.Exit(1)
+		}
+		if err := ipamController.SetupWithManager(mgr); err != nil {
+			setupLog.Error(err, "unable to create controller", "controller", "IPAMController")
+			os.Exit(1)
+		}
+	}
+
 	if err := addNodeController(mgr, &opt); err != nil {
 		setupLog.Error(err, "unable to create controller", "controller", "NodeController")
 		os.Exit(1)
 	}
+
+	if err := addGossipController(mgr, &opt); err != nil {
+		setupLog.Error(err, "unable to create controller", "controller", "GossipController")
+		os.Exit(1)
+	}
+
 	// +kubebuilder:scaffold:builder
 
 	setupLog.Info("starting manager")
@@ -142,6 +173,10 @@ func buildScheme() error {
 	if err := corev1.AddToScheme(scheme); err != nil {
 		return fmt.Errorf("error registering corev1: %v", err)
 	}
+	// Needed so that the leader-election system can post events
+	if err := coordinationv1.AddToScheme(scheme); err != nil {
+		return fmt.Errorf("error registering coordinationv1: %v", err)
+	}
 	return nil
 }
 
@@ -211,3 +246,25 @@ func addNodeController(mgr manager.Manager, opt *config.Options) error {
 
 	return nil
 }
+
+func addGossipController(mgr manager.Manager, opt *config.Options) error {
+	if opt.Discovery == nil || !opt.Discovery.Enabled {
+		return nil
+	}
+
+	configMapID := types.NamespacedName{
+		Namespace: "kube-system",
+		Name:      "coredns",
+	}
+
+	controller, err := controllers.NewHostsReconciler(mgr, configMapID)
+	if err != nil {
+		return err
+	}
+
+	if err := controller.SetupWithManager(mgr); err != nil {
+		return err
+	}
+
+	return nil
+}
