@@ -19,7 +19,7 @@ package main
 import (
 	"bytes"
 	"context"
-	"io/ioutil"
+	"os"
 	"path"
 	"strings"
 	"testing"
@@ -44,12 +44,12 @@ var MagicTimestamp = metav1.Time{Time: time.Date(2017, 1, 1, 0, 0, 0, 0, time.UT
 
 // TestCreateClusterMinimal runs kops create cluster minimal.example.com --zones us-test-1a
 func TestCreateClusterMinimal(t *testing.T) {
-	runCreateClusterIntegrationTest(t, "../../tests/integration/create_cluster/minimal-1.17", "v1alpha2")
 	runCreateClusterIntegrationTest(t, "../../tests/integration/create_cluster/minimal-1.18", "v1alpha2")
 	runCreateClusterIntegrationTest(t, "../../tests/integration/create_cluster/minimal-1.19", "v1alpha2")
 	runCreateClusterIntegrationTest(t, "../../tests/integration/create_cluster/minimal-1.20", "v1alpha2")
 	runCreateClusterIntegrationTest(t, "../../tests/integration/create_cluster/minimal-1.21", "v1alpha2")
 	runCreateClusterIntegrationTest(t, "../../tests/integration/create_cluster/minimal-1.22", "v1alpha2")
+	runCreateClusterIntegrationTest(t, "../../tests/integration/create_cluster/minimal-1.23", "v1alpha2")
 }
 
 // TestCreateClusterOverride tests the override flag
@@ -179,7 +179,7 @@ func runCreateClusterIntegrationTest(t *testing.T, srcDir string, version string
 	factory := util.NewFactory(factoryOptions)
 
 	{
-		optionsBytes, err := ioutil.ReadFile(path.Join(srcDir, optionsYAML))
+		optionsBytes, err := os.ReadFile(path.Join(srcDir, optionsYAML))
 		if err != nil {
 			t.Fatalf("error reading options file: %v", err)
 		}
@@ -197,7 +197,7 @@ func runCreateClusterIntegrationTest(t *testing.T, srcDir string, version string
 
 		// Use the public key we produced
 		{
-			publicKey, err := ioutil.ReadFile(publicKeyPath)
+			publicKey, err := os.ReadFile(publicKeyPath)
 			if err != nil {
 				t.Fatalf("error reading public key %q: %v", publicKeyPath, err)
 			}
@@ -260,6 +260,25 @@ func runCreateClusterIntegrationTest(t *testing.T, srcDir string, version string
 		yamlAll = append(yamlAll, actualYAML)
 	}
 
+	// Compare additional objects
+	addons, err := clientset.AddonsFor(&clusters.Items[0]).List()
+	if err != nil {
+		t.Fatalf("error listing addons: %v", err)
+	}
+
+	for _, addon := range addons {
+		u := addon.ToUnstructured()
+
+		actualYAMLBytes, err := kopscodecs.ToVersionedYamlWithVersion(u, schema.GroupVersion{Group: "kops.k8s.io", Version: version})
+		if err != nil {
+			t.Fatalf("unexpected error serializing Addon: %v", err)
+		}
+
+		actualYAML := strings.TrimSpace(string(actualYAMLBytes))
+
+		yamlAll = append(yamlAll, actualYAML)
+	}
+
 	actualYAML := strings.Join(yamlAll, "\n\n---\n\n")
 	golden.AssertMatchesFile(t, actualYAML, path.Join(srcDir, expectedClusterPath))
 }
