@@ -108,7 +108,7 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 		}
 	}
 
-	if b.UseEtcdManager() {
+	{
 		c.AddTask(&nodetasks.File{
 			Path:     filepath.Join(pathSrvKAPI, "etcd-ca.crt"),
 			Contents: fi.NewStringResource(b.NodeupConfig.CAs["etcd-clients-ca"]),
@@ -130,8 +130,6 @@ func (b *KubeAPIServerBuilder) Build(c *fi.ModelBuilderContext) error {
 		if err := issueCert.AddFileTasks(c, pathSrvKAPI, issueCert.Name, "", nil); err != nil {
 			return err
 		}
-	} else if b.UseEtcdTLS() {
-		kubeAPIServer.EtcdCAFile = filepath.Join(b.PathSrvKubernetes(), "ca.crt")
 	}
 	kubeAPIServer.EtcdCertFile = filepath.Join(pathSrvKAPI, "etcd-client.crt")
 	kubeAPIServer.EtcdKeyFile = filepath.Join(pathSrvKAPI, "etcd-client.key")
@@ -255,7 +253,7 @@ func (b *KubeAPIServerBuilder) writeAuthenticationConfig(c *fi.ModelBuilderConte
 		return nil
 	}
 
-	if b.Cluster.Spec.Authentication.Aws != nil {
+	if b.Cluster.Spec.Authentication.AWS != nil {
 		id := "aws-iam-authenticator"
 		kubeAPIServer.AuthenticationTokenWebhookConfigFile = fi.String(PathAuthnConfig)
 
@@ -493,12 +491,7 @@ func (b *KubeAPIServerBuilder) writeStaticCredentials(c *fi.ModelBuilderContext,
 
 	// Support for basic auth was deprecated 1.16 and removed in 1.19
 	// https://github.com/kubernetes/kubernetes/pull/89069
-	if b.IsKubernetesLT("1.18") {
-		kubeAPIServer.TokenAuthFile = filepath.Join(pathSrvKAPI, "known_tokens.csv")
-		if kubeAPIServer.DisableBasicAuth == nil || !*kubeAPIServer.DisableBasicAuth {
-			kubeAPIServer.BasicAuthFile = filepath.Join(pathSrvKAPI, "basic_auth.csv")
-		}
-	} else if b.IsKubernetesLT("1.19") {
+	if b.IsKubernetesLT("1.19") {
 		if kubeAPIServer.DisableBasicAuth != nil && !*kubeAPIServer.DisableBasicAuth {
 			kubeAPIServer.BasicAuthFile = filepath.Join(pathSrvKAPI, "basic_auth.csv")
 		}
@@ -605,37 +598,21 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 	resourceLimits := v1.ResourceList{}
 
 	cpuRequest := resource.MustParse("150m")
-	if kubeAPIServer.CPURequest != "" {
-		var err error
-		cpuRequest, err = resource.ParseQuantity(kubeAPIServer.CPURequest)
-		if err != nil {
-			return nil, fmt.Errorf("error parsing CPURequest=%q", kubeAPIServer.CPURequest)
-		}
+	if kubeAPIServer.CPURequest != nil {
+		cpuRequest = *kubeAPIServer.CPURequest
 	}
 	resourceRequests["cpu"] = cpuRequest
 
-	if kubeAPIServer.CPULimit != "" {
-		cpuLimit, err := resource.ParseQuantity(kubeAPIServer.CPULimit)
-		if err != nil {
-			return nil, fmt.Errorf("error parsing CPULimit=%q", kubeAPIServer.CPULimit)
-		}
-		resourceLimits["cpu"] = cpuLimit
+	if kubeAPIServer.CPULimit != nil {
+		resourceLimits["cpu"] = *kubeAPIServer.CPULimit
 	}
 
-	if kubeAPIServer.MemoryRequest != "" {
-		memoryRequest, err := resource.ParseQuantity(kubeAPIServer.MemoryRequest)
-		if err != nil {
-			return nil, fmt.Errorf("error parsing MemoryRequest=%q", kubeAPIServer.MemoryRequest)
-		}
-		resourceRequests["memory"] = memoryRequest
+	if kubeAPIServer.MemoryRequest != nil {
+		resourceRequests["memory"] = *kubeAPIServer.MemoryRequest
 	}
 
-	if kubeAPIServer.MemoryLimit != "" {
-		memoryLimit, err := resource.ParseQuantity(kubeAPIServer.MemoryLimit)
-		if err != nil {
-			return nil, fmt.Errorf("error parsing MemoryLimit=%q", kubeAPIServer.MemoryLimit)
-		}
-		resourceLimits["memory"] = memoryLimit
+	if kubeAPIServer.MemoryLimit != nil {
+		resourceLimits["memory"] = *kubeAPIServer.MemoryLimit
 	}
 
 	image := kubeAPIServer.Image
@@ -648,7 +625,7 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 		Image: image,
 		Env:   proxy.GetProxyEnvVars(b.Cluster.Spec.EgressProxy),
 		LivenessProbe: &v1.Probe{
-			Handler: v1.Handler{
+			ProbeHandler: v1.ProbeHandler{
 				HTTPGet: probeAction,
 			},
 			InitialDelaySeconds: 45,
@@ -679,17 +656,27 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 	addHostPathMapping(pod, container, "logfile", "/var/log/kube-apiserver.log").ReadOnly = false
 	// We use lighter containers that don't include shells
 	// But they have richer logging support via klog
-	container.Command = []string{"/usr/local/bin/kube-apiserver"}
-	if kubeAPIServer.LogFormat != "" && kubeAPIServer.LogFormat != "text" {
-		// When logging-format is not text, some flags are not accepted.
-		// https://github.com/kubernetes/kops/issues/13245
-		container.Args = sortedStrings(flags)
+	if b.IsKubernetesGTE("1.23") {
+		container.Command = []string{"/go-runner"}
+		container.Args = []string{
+			"--log-file=/var/log/kube-apiserver.log",
+			"--also-stdout",
+			"/usr/local/bin/kube-apiserver",
+		}
+		container.Args = append(container.Args, sortedStrings(flags)...)
 	} else {
-		container.Args = append(
-			sortedStrings(flags),
-			"--logtostderr=false", // https://github.com/kubernetes/klog/issues/60
-			"--alsologtostderr",
-			"--log-file=/var/log/kube-apiserver.log")
+		container.Command = []string{"/usr/local/bin/kube-apiserver"}
+		if kubeAPIServer.LogFormat != "" && kubeAPIServer.LogFormat != "text" {
+			// When logging-format is not text, some flags are not accepted.
+			// https://github.com/kubernetes/kops/issues/13245
+			container.Args = sortedStrings(flags)
+		} else {
+			container.Args = append(
+				sortedStrings(flags),
+				"--logtostderr=false", // https://github.com/kubernetes/klog/issues/60
+				"--alsologtostderr",
+				"--log-file=/var/log/kube-apiserver.log")
+		}
 	}
 
 	for _, path := range b.SSLHostPaths() {
@@ -724,7 +711,7 @@ func (b *KubeAPIServerBuilder) buildPod(kubeAPIServer *kops.KubeAPIServerConfig)
 	}
 
 	if b.Cluster.Spec.Authentication != nil {
-		if b.Cluster.Spec.Authentication.Kopeio != nil || b.Cluster.Spec.Authentication.Aws != nil {
+		if b.Cluster.Spec.Authentication.Kopeio != nil || b.Cluster.Spec.Authentication.AWS != nil {
 			addHostPathMapping(pod, container, "authn-config", PathAuthnConfig)
 		}
 	}
@@ -748,7 +735,7 @@ func (b *KubeAPIServerBuilder) buildAnnotations() map[string]string {
 	annotations["kubectl.kubernetes.io/default-container"] = "kube-apiserver"
 
 	if b.Cluster.Spec.API != nil {
-		if b.Cluster.Spec.API.LoadBalancer == nil || !b.Cluster.Spec.API.LoadBalancer.UseForInternalApi {
+		if b.Cluster.Spec.API.LoadBalancer == nil || !b.Cluster.Spec.API.LoadBalancer.UseForInternalAPI {
 			annotations["dns.alpha.kubernetes.io/internal"] = b.Cluster.Spec.MasterInternalName
 		}
 
