@@ -17,6 +17,7 @@ limitations under the License.
 package model
 
 import (
+	"bytes"
 	"fmt"
 	"net"
 	"os"
@@ -31,6 +32,11 @@ import (
 
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/klog/v2"
+	kubelet "k8s.io/kubelet/config/v1beta1"
+
+	"k8s.io/apimachinery/pkg/runtime"
+	"k8s.io/apimachinery/pkg/runtime/serializer"
+
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/flagbuilder"
 	"k8s.io/kops/pkg/nodelabels"
@@ -48,6 +54,8 @@ const (
 
 	// kubeletService is the name of the kubelet service
 	kubeletService = "kubelet.service"
+
+	kubeletConfigFilePath = "/var/lib/kubelet/kubelet.conf"
 )
 
 // KubeletBuilder installs kubelet
@@ -69,6 +77,15 @@ func (b *KubeletBuilder) Build(c *fi.ModelBuilderContext) error {
 		return fmt.Errorf("error building kubelet config: %v", err)
 	}
 
+	{
+		t, err := buildKubeletComponentConfig(kubeletConfig)
+		if err != nil {
+			return err
+		}
+
+		c.AddTask(t)
+	}
+
 	{
 		t, err := b.buildSystemdEnvironmentFile(kubeletConfig)
 		if err != nil {
@@ -161,6 +178,42 @@ func (b *KubeletBuilder) Build(c *fi.ModelBuilderContext) error {
 	return nil
 }
 
+func buildKubeletComponentConfig(kubeletConfig *kops.KubeletConfigSpec) (*nodetasks.File, error) {
+	componentConfig := kubelet.KubeletConfiguration{}
+	if kubeletConfig.ShutdownGracePeriod != nil {
+		componentConfig.ShutdownGracePeriod = *kubeletConfig.ShutdownGracePeriod
+	}
+	if kubeletConfig.ShutdownGracePeriodCriticalPods != nil {
+		componentConfig.ShutdownGracePeriodCriticalPods = *kubeletConfig.ShutdownGracePeriodCriticalPods
+	}
+
+	s := runtime.NewScheme()
+	if err := kubelet.AddToScheme(s); err != nil {
+		return nil, err
+	}
+
+	gv := kubelet.SchemeGroupVersion
+	codecFactory := serializer.NewCodecFactory(s)
+	info, ok := runtime.SerializerInfoForMediaType(codecFactory.SupportedMediaTypes(), "application/yaml")
+	if !ok {
+		return nil, fmt.Errorf("failed to find serializer")
+	}
+	encoder := codecFactory.EncoderForVersion(info.Serializer, gv)
+	var w bytes.Buffer
+	if err := encoder.Encode(&componentConfig, &w); err != nil {
+		return nil, err
+	}
+
+	t := &nodetasks.File{
+		Path:           "/var/lib/kubelet/kubelet.conf",
+		Contents:       fi.NewBytesResource(w.Bytes()),
+		Type:           nodetasks.FileType_File,
+		BeforeServices: []string{kubeletService},
+	}
+
+	return t, nil
+}
+
 // kubeletPath returns the path of the kubelet based on distro
 func (b *KubeletBuilder) kubeletPath() string {
 	kubeletCommand := "/usr/local/bin/kubelet"
@@ -190,13 +243,6 @@ func (b *KubeletBuilder) buildSystemdEnvironmentFile(kubeletConfig *kops.Kubelet
 		kubeletConfig.BootstrapKubeconfig = ""
 	}
 
-	if kubeletConfig.ExperimentalAllowedUnsafeSysctls != nil {
-		// The ExperimentalAllowedUnsafeSysctls flag was renamed in k/k #63717
-		klog.V(1).Info("ExperimentalAllowedUnsafeSysctls was renamed in k8s 1.11+, please use AllowedUnsafeSysctls instead.")
-		kubeletConfig.AllowedUnsafeSysctls = append(kubeletConfig.ExperimentalAllowedUnsafeSysctls, kubeletConfig.AllowedUnsafeSysctls...)
-		kubeletConfig.ExperimentalAllowedUnsafeSysctls = nil
-	}
-
 	// TODO: Dump the separate file for flags - just complexity!
 	flags, err := flagbuilder.BuildFlags(kubeletConfig)
 	if err != nil {
@@ -250,6 +296,8 @@ func (b *KubeletBuilder) buildSystemdEnvironmentFile(kubeletConfig *kops.Kubelet
 		flags += " --node-ip=::"
 	}
 
+	flags += " --config=" + kubeletConfigFilePath
+
 	sysconfig := "DAEMON_ARGS=\"" + flags + "\"\n"
 	// Makes kubelet read /root/.docker/config.json properly
 	sysconfig = sysconfig + "HOME=\"/root" + "\"\n"
@@ -626,5 +674,6 @@ func (b *KubeletBuilder) kubeletNames() ([]string, error) {
 		return nil, fmt.Errorf("error describing instances: %v", err)
 	}
 
-	return awsup.GetInstanceCertificateNames(result)
+	useInstanceIDForNodeName := b.Cluster.Spec.ExternalCloudControllerManager != nil && b.IsKubernetesGTE("1.22")
+	return awsup.GetInstanceCertificateNames(result, useInstanceIDForNodeName)
 }
