@@ -30,7 +30,7 @@ var _ iam.Subject = &ServiceAccount{}
 // BuildAWSPolicy generates a custom policy for a ServiceAccount IAM role.
 func (r *ServiceAccount) BuildAWSPolicy(b *iam.PolicyBuilder) (*iam.Policy, error) {
 	clusterName := b.Cluster.ObjectMeta.Name
-	p := iam.NewPolicy(clusterName)
+	p := iam.NewPolicy(clusterName, b.Partition)
 
 	iam.AddAWSLoadbalancerControllerPermissions(p, b.Partition)
 
