@@ -23,16 +23,14 @@ import (
 
 // ServiceAccount represents the service-account used by the dns-controller.
 // It implements iam.Subject to get AWS IAM permissions.
-type ServiceAccount struct {
-}
+type ServiceAccount struct{}
 
 var _ iam.Subject = &ServiceAccount{}
 
 // BuildAWSPolicy generates a custom policy for a ServiceAccount IAM role.
 func (r *ServiceAccount) BuildAWSPolicy(b *iam.PolicyBuilder) (*iam.Policy, error) {
-	p := &iam.Policy{
-		Version: iam.PolicyDefaultVersion,
-	}
+	clusterName := b.Cluster.ObjectMeta.Name
+	p := iam.NewPolicy(clusterName, b.Partition)
 
 	iam.AddDNSControllerPermissions(b, p)
 
