@@ -90,7 +90,9 @@ function kops-download-from-base() {
 }
 
 function kops-base-from-marker() {
-    if [[ "${1}" == "latest" ]]; then
+    if [[ "${1}" =~ ^https: ]]; then
+        echo "${1}"
+    elif [[ "${1}" == "latest" ]]; then
         curl -s "https://storage.googleapis.com/kops-ci/bin/latest-ci-updown-green.txt"
     else
         curl -s "https://storage.googleapis.com/k8s-staging-kops/kops/releases/markers/release-${1}/latest-ci.txt"
@@ -108,6 +110,9 @@ function kops-acquire-latest() {
          fi
          $KUBETEST2 --build
          KOPS="${REPO_ROOT}/.bazelbuild/dist/linux/amd64/kops"
+         KOPS_BASE_URL=$(cat "${REPO_ROOT}/.kubetest2/kops-base-url")
+         export KOPS_BASE_URL
+         echo "KOPS_BASE_URL=$KOPS_BASE_URL"
     fi
 }
 
@@ -117,9 +122,12 @@ function kops-up() {
     if [[ -n "${ZONES-}" ]]; then
         create_args="${create_args} --zones=${ZONES}"
     fi
+    if [[ -z "${K8S_VERSION-}" ]]; then
+        K8S_VERSION="1.22.1"
+    fi
     ${KUBETEST2} \
         --up \
         --kops-binary-path="${KOPS}" \
-        --kubernetes-version="1.22.1" \
+        --kubernetes-version="${K8S_VERSION}" \
         --create-args="${create_args}"
 }
\ No newline at end of file
