@@ -31,6 +31,7 @@ type ComputeClient interface {
 	Subnetworks() SubnetworkClient
 	Routes() RouteClient
 	ForwardingRules() ForwardingRuleClient
+	HTTPHealthChecks() HttpHealthChecksClient
 	Addresses() AddressClient
 	Firewalls() FirewallClient
 	Routers() RouterClient
@@ -99,6 +100,12 @@ func (c *computeClientImpl) ForwardingRules() ForwardingRuleClient {
 	}
 }
 
+func (c *computeClientImpl) HTTPHealthChecks() HttpHealthChecksClient {
+	return &httpHealthCheckClientImpl{
+		srv: c.srv.HttpHealthChecks,
+	}
+}
+
 func (c *computeClientImpl) Addresses() AddressClient {
 	return &addressClientImpl{
 		srv: c.srv.Addresses,
@@ -208,6 +215,8 @@ func (c *zoneClientImpl) List(ctx context.Context, project string) ([]*compute.Z
 type NetworkClient interface {
 	Insert(project string, nw *compute.Network) (*compute.Operation, error)
 	Get(project, name string) (*compute.Network, error)
+	Delete(project, name string) (*compute.Operation, error)
+	List(project string) (*compute.NetworkList, error)
 }
 
 type networkClientImpl struct {
@@ -220,10 +229,18 @@ func (c *networkClientImpl) Insert(project string, nw *compute.Network) (*comput
 	return c.srv.Insert(project, nw).Do()
 }
 
+func (c *networkClientImpl) Delete(project string, name string) (*compute.Operation, error) {
+	return c.srv.Delete(project, name).Do()
+}
+
 func (c *networkClientImpl) Get(project, name string) (*compute.Network, error) {
 	return c.srv.Get(project, name).Do()
 }
 
+func (c *networkClientImpl) List(project string) (*compute.NetworkList, error) {
+	return c.srv.List(project).Do()
+}
+
 type SubnetworkClient interface {
 	Insert(project, region string, subnet *compute.Subnetwork) (*compute.Operation, error)
 	Patch(project, region, name string, subnet *compute.Subnetwork) (*compute.Operation, error)
@@ -327,6 +344,42 @@ func (c *forwardingRuleClientImpl) List(ctx context.Context, project, region str
 	return frs, nil
 }
 
+type HttpHealthChecksClient interface {
+	Insert(project string, fr *compute.HttpHealthCheck) (*compute.Operation, error)
+	Delete(project, name string) (*compute.Operation, error)
+	Get(project, name string) (*compute.HttpHealthCheck, error)
+	List(ctx context.Context, project string) ([]*compute.HttpHealthCheck, error)
+}
+
+type httpHealthCheckClientImpl struct {
+	srv *compute.HttpHealthChecksService
+}
+
+var _ HttpHealthChecksClient = &httpHealthCheckClientImpl{}
+
+func (c *httpHealthCheckClientImpl) Insert(project string, fr *compute.HttpHealthCheck) (*compute.Operation, error) {
+	return c.srv.Insert(project, fr).Do()
+}
+
+func (c *httpHealthCheckClientImpl) Delete(project, name string) (*compute.Operation, error) {
+	return c.srv.Delete(project, name).Do()
+}
+
+func (c *httpHealthCheckClientImpl) Get(project, name string) (*compute.HttpHealthCheck, error) {
+	return c.srv.Get(project, name).Do()
+}
+
+func (c *httpHealthCheckClientImpl) List(ctx context.Context, project string) ([]*compute.HttpHealthCheck, error) {
+	var hcs []*compute.HttpHealthCheck
+	if err := c.srv.List(project).Pages(ctx, func(p *compute.HttpHealthCheckList) error {
+		hcs = append(hcs, p.Items...)
+		return nil
+	}); err != nil {
+		return nil, err
+	}
+	return hcs, nil
+}
+
 type AddressClient interface {
 	Insert(project, region string, addr *compute.Address) (*compute.Operation, error)
 	Delete(project, region, name string) (*compute.Operation, error)
