@@ -30,10 +30,10 @@ import (
 	"k8s.io/kops"
 	api "k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/apis/kops/model"
-	version "k8s.io/kops/pkg/apis/kops/util"
 	"k8s.io/kops/pkg/client/simple"
 	"k8s.io/kops/pkg/dns"
 	"k8s.io/kops/pkg/featureflag"
+	"k8s.io/kops/pkg/zones"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/aliup"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
@@ -128,6 +128,9 @@ type NewClusterOptions struct {
 	NodeCount int32
 	// Bastion enables the creation of a Bastion instance.
 	Bastion bool
+	// BastionLoadBalancerType is the bastion loadbalancer type to use; "public" or "internal".
+	// Defaults to "public".
+	BastionLoadBalancerType string
 
 	// Networking is the networking provider/node to use.
 	Networking string
@@ -240,7 +243,7 @@ func NewCluster(opt *NewClusterOptions, clientset simple.Clientset) (*NewCluster
 	cluster.Spec.CloudProvider = opt.CloudProvider
 	if cluster.Spec.CloudProvider == "" {
 		for _, zone := range allZones.List() {
-			cloud, known := fi.GuessCloudForZone(zone)
+			cloud, known := zones.GuessCloudForZone(zone)
 			if known {
 				klog.Infof("Inferred %q cloud provider from zone %q", cloud, zone)
 				cluster.Spec.CloudProvider = string(cloud)
@@ -471,10 +474,19 @@ func setupZones(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.Stri
 					Name:   subnetName,
 					Region: region,
 				}
+				if len(opt.SubnetIDs) != 0 {
+					// We don't support multi-region clusters, so we can't have more than one subnet
+					if len(opt.SubnetIDs) != 1 {
+						return nil, fmt.Errorf("expected exactly one subnet for GCE, got %d", len(opt.SubnetIDs))
+					}
+					providerID := opt.SubnetIDs[0]
+					subnet.ProviderID = providerID
+				}
 				cluster.Spec.Subnets = append(cluster.Spec.Subnets, *subnet)
 			}
 			zoneToSubnetMap[zoneName] = subnet
 		}
+
 		return zoneToSubnetMap, nil
 
 	case api.CloudProviderDO:
@@ -639,6 +651,8 @@ func getOpenstackZoneToSubnetProviderID(spec *api.ClusterSpec, zones []string, s
 }
 
 func setupMasters(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap map[string]*api.ClusterSubnetSpec) ([]*api.InstanceGroup, error) {
+	cloudProvider := api.CloudProviderID(cluster.Spec.CloudProvider)
+
 	var masters []*api.InstanceGroup
 
 	// Build the master subnets
@@ -675,7 +689,7 @@ func setupMasters(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap
 		for i := 0; i < int(masterCount); i++ {
 			zone := masterZones[i%len(masterZones)]
 			name := zone
-			if api.CloudProviderID(cluster.Spec.CloudProvider) == api.CloudProviderDO {
+			if cloudProvider == api.CloudProviderDO {
 				if int(masterCount) >= len(masterZones) {
 					name += "-" + strconv.Itoa(1+(i/len(masterZones)))
 				}
@@ -697,14 +711,16 @@ func setupMasters(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap
 			}
 
 			g.Spec.Subnets = []string{subnet.Name}
-			if cp := api.CloudProviderID(cluster.Spec.CloudProvider); cp == api.CloudProviderGCE || cp == api.CloudProviderAzure {
+			if cloudProvider == api.CloudProviderGCE || cloudProvider == api.CloudProviderAzure {
 				g.Spec.Zones = []string{zone}
 			}
 
 			if cluster.IsKubernetesGTE("1.22") {
-				g.Spec.InstanceMetadata = &api.InstanceMetadataOptions{
-					HTTPPutResponseHopLimit: fi.Int64(3),
-					HTTPTokens:              fi.String("required"),
+				if cloudProvider == api.CloudProviderAWS {
+					g.Spec.InstanceMetadata = &api.InstanceMetadataOptions{
+						HTTPPutResponseHopLimit: fi.Int64(3),
+						HTTPTokens:              fi.String("required"),
+					}
 				}
 			}
 
@@ -743,7 +759,7 @@ func setupMasters(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap
 		encryptEtcdStorage := false
 		if opt.EncryptEtcdStorage != nil {
 			encryptEtcdStorage = fi.BoolValue(opt.EncryptEtcdStorage)
-		} else if api.CloudProviderID(cluster.Spec.CloudProvider) == api.CloudProviderAWS {
+		} else if cloudProvider == api.CloudProviderAWS {
 			encryptEtcdStorage = true
 		}
 		for _, etcdCluster := range clusters {
@@ -786,6 +802,8 @@ func trimCommonPrefix(names []string) []string {
 }
 
 func setupNodes(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap map[string]*api.ClusterSubnetSpec) ([]*api.InstanceGroup, error) {
+	cloudProvider := api.CloudProviderID(cluster.Spec.CloudProvider)
+
 	var nodes []*api.InstanceGroup
 
 	// The node count is the number of zones unless explicitly set
@@ -818,14 +836,16 @@ func setupNodes(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap ma
 		}
 
 		g.Spec.Subnets = []string{subnet.Name}
-		if cp := api.CloudProviderID(cluster.Spec.CloudProvider); cp == api.CloudProviderGCE || cp == api.CloudProviderAzure {
+		if cloudProvider == api.CloudProviderGCE || cloudProvider == api.CloudProviderAzure {
 			g.Spec.Zones = []string{zone}
 		}
 
 		if cluster.IsKubernetesGTE("1.22") {
-			g.Spec.InstanceMetadata = &api.InstanceMetadataOptions{
-				HTTPPutResponseHopLimit: fi.Int64(1),
-				HTTPTokens:              fi.String("required"),
+			if cloudProvider == api.CloudProviderAWS {
+				g.Spec.InstanceMetadata = &api.InstanceMetadataOptions{
+					HTTPPutResponseHopLimit: fi.Int64(1),
+					HTTPTokens:              fi.String("required"),
+				}
 			}
 		}
 
@@ -836,6 +856,8 @@ func setupNodes(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap ma
 }
 
 func setupAPIServers(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetMap map[string]*api.ClusterSubnetSpec) ([]*api.InstanceGroup, error) {
+	cloudProvider := api.CloudProviderID(cluster.Spec.CloudProvider)
+
 	var nodes []*api.InstanceGroup
 
 	numZones := len(opt.Zones)
@@ -866,14 +888,16 @@ func setupAPIServers(opt *NewClusterOptions, cluster *api.Cluster, zoneToSubnetM
 		}
 
 		g.Spec.Subnets = []string{subnet.Name}
-		if cp := api.CloudProviderID(cluster.Spec.CloudProvider); cp == api.CloudProviderGCE || cp == api.CloudProviderAzure {
+		if cloudProvider == api.CloudProviderGCE || cloudProvider == api.CloudProviderAzure {
 			g.Spec.Zones = []string{zone}
 		}
 
 		if cluster.IsKubernetesGTE("1.22") {
-			g.Spec.InstanceMetadata = &api.InstanceMetadataOptions{
-				HTTPPutResponseHopLimit: fi.Int64(1),
-				HTTPTokens:              fi.String("required"),
+			if cloudProvider == api.CloudProviderAWS {
+				g.Spec.InstanceMetadata = &api.InstanceMetadataOptions{
+					HTTPPutResponseHopLimit: fi.Int64(1),
+					HTTPTokens:              fi.String("required"),
+				}
 			}
 		}
 
@@ -930,8 +954,6 @@ func setupNetworking(opt *NewClusterOptions, cluster *api.Cluster) error {
 	case "cilium-etcd":
 		addCiliumNetwork(cluster)
 		cluster.Spec.Networking.Cilium.EtcdManaged = true
-	case "lyftvpc":
-		cluster.Spec.Networking.LyftVPC = &api.LyftVPCNetworkingSpec{}
 	case "gce":
 		cluster.Spec.Networking.GCE = &api.GCENetworkingSpec{}
 	default:
@@ -962,19 +984,6 @@ func setupTopology(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.S
 			cluster.Spec.Subnets[i].Type = api.SubnetTypePublic
 		}
 
-		if opt.IPv6 {
-			if api.CloudProviderID(cluster.Spec.CloudProvider) == api.CloudProviderAWS {
-				klog.Warningf("IPv6 support is EXPERIMENTAL and can be changed or removed at any time in the future!!!")
-				for i := range cluster.Spec.Subnets {
-					// Start IPv6 CIDR numbering from "1" to reserve /64#0 for later use
-					// with NonMasqueradeCIDR, ClusterCIDR and ServiceClusterIPRange
-					cluster.Spec.Subnets[i].IPv6CIDR = fmt.Sprintf("/64#%x", i+1)
-				}
-			} else {
-				klog.Errorf("IPv6 support is available only on AWS")
-			}
-		}
-
 	case api.TopologyPrivate:
 		if cluster.Spec.Networking.Kubenet != nil {
 			return nil, fmt.Errorf("invalid networking option %s. Kubenet does not support private topology", opt.Networking)
@@ -988,8 +997,6 @@ func setupTopology(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.S
 			cluster.Spec.Subnets[i].Type = api.SubnetTypePrivate
 		}
 
-		var utilitySubnets []api.ClusterSubnetSpec
-
 		var zoneToSubnetProviderID map[string]string
 		var err error
 		if len(opt.Zones) > 0 && len(opt.UtilitySubnetIDs) > 0 {
@@ -1009,22 +1016,33 @@ func setupTopology(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.S
 			}
 		}
 
-		for _, s := range cluster.Spec.Subnets {
-			if s.Type == api.SubnetTypeUtility {
-				continue
+		addUtilitySubnets := true
+		switch api.CloudProviderID(cluster.Spec.CloudProvider) {
+		case api.CloudProviderGCE:
+			// GCE does not need utility subnets
+			addUtilitySubnets = false
+		}
+
+		if addUtilitySubnets {
+			var utilitySubnets []api.ClusterSubnetSpec
+
+			for _, s := range cluster.Spec.Subnets {
+				if s.Type == api.SubnetTypeUtility {
+					continue
+				}
+				subnet := api.ClusterSubnetSpec{
+					Name:   "utility-" + s.Name,
+					Zone:   s.Zone,
+					Type:   api.SubnetTypeUtility,
+					Region: s.Region,
+				}
+				if subnetID, ok := zoneToSubnetProviderID[s.Zone]; ok {
+					subnet.ProviderID = subnetID
+				}
+				utilitySubnets = append(utilitySubnets, subnet)
 			}
-			subnet := api.ClusterSubnetSpec{
-				Name:   "utility-" + s.Name,
-				Zone:   s.Zone,
-				Type:   api.SubnetTypeUtility,
-				Region: s.Region,
-			}
-			if subnetID, ok := zoneToSubnetProviderID[s.Zone]; ok {
-				subnet.ProviderID = subnetID
-			}
-			utilitySubnets = append(utilitySubnets, subnet)
+			cluster.Spec.Subnets = append(cluster.Spec.Subnets, utilitySubnets...)
 		}
-		cluster.Spec.Subnets = append(cluster.Spec.Subnets, utilitySubnets...)
 
 		if opt.Bastion {
 			bastionGroup := &api.InstanceGroup{}
@@ -1034,7 +1052,7 @@ func setupTopology(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.S
 
 			if !dns.IsGossipHostname(cluster.Name) {
 				cluster.Spec.Topology.Bastion = &api.BastionSpec{
-					BastionPublicName: "bastion." + cluster.Name,
+					PublicName: "bastion." + cluster.Name,
 				}
 			}
 			if api.CloudProviderID(cluster.Spec.CloudProvider) == api.CloudProviderGCE {
@@ -1054,6 +1072,18 @@ func setupTopology(opt *NewClusterOptions, cluster *api.Cluster, allZones sets.S
 		return nil, fmt.Errorf("invalid topology %s", opt.Topology)
 	}
 
+	if opt.IPv6 {
+		cluster.Spec.NonMasqueradeCIDR = "::/0"
+		cluster.Spec.ExternalCloudControllerManager = &api.CloudControllerManagerConfig{}
+		if api.CloudProviderID(cluster.Spec.CloudProvider) == api.CloudProviderAWS {
+			for i := range cluster.Spec.Subnets {
+				cluster.Spec.Subnets[i].IPv6CIDR = fmt.Sprintf("/64#%x", i)
+			}
+		} else {
+			klog.Errorf("IPv6 support is available only on AWS")
+		}
+	}
+
 	cluster.Spec.Topology.DNS = &api.DNSSpec{}
 	switch strings.ToLower(opt.DNSType) {
 	case "public", "":
@@ -1214,25 +1244,10 @@ func createEtcdCluster(etcdCluster string, masters []*api.InstanceGroup, encrypt
 func addCiliumNetwork(cluster *api.Cluster) {
 	cilium := &api.CiliumNetworkingSpec{}
 	cluster.Spec.Networking.Cilium = cilium
-	nodeport := false
-	if cluster.Spec.KubernetesVersion == "" {
-		nodeport = true
-	} else {
-		k8sVersion, err := version.ParseKubernetesVersion(cluster.Spec.KubernetesVersion)
-		if err == nil {
-			if version.IsKubernetesGTE("1.18", *k8sVersion) {
-				nodeport = true
-			}
-		} else {
-			klog.Error(err.Error())
-		}
-	}
-	if nodeport {
-		cilium.EnableNodePort = true
-		if cluster.Spec.KubeProxy == nil {
-			cluster.Spec.KubeProxy = &api.KubeProxyConfig{}
-		}
-		enabled := false
-		cluster.Spec.KubeProxy.Enabled = &enabled
+	cilium.EnableNodePort = true
+	if cluster.Spec.KubeProxy == nil {
+		cluster.Spec.KubeProxy = &api.KubeProxyConfig{}
 	}
+	enabled := false
+	cluster.Spec.KubeProxy.Enabled = &enabled
 }
