@@ -277,7 +277,7 @@ func generateInstanceName(e *Instance) (string, error) {
 }
 
 func (_ *Instance) RenderOpenstack(t *openstack.OpenstackAPITarget, a, e, changes *Instance) error {
-	cloud := t.Cloud.(openstack.OpenstackCloud)
+	cloud := t.Cloud
 	if a == nil {
 		serverName, err := generateInstanceName(e)
 		if err != nil {
@@ -370,8 +370,7 @@ func (_ *Instance) RenderOpenstack(t *openstack.OpenstackAPITarget, a, e, change
 }
 
 func associateFloatingIP(t *openstack.OpenstackAPITarget, e *Instance) error {
-	cloud := t.Cloud.(openstack.OpenstackCloud)
-	client := cloud.NetworkingClient()
+	client := t.Cloud.NetworkingClient()
 
 	_, err := l3floatingip.Update(client, fi.StringValue(e.FloatingIP.ID), l3floatingip.UpdateOpts{
 		PortID: e.Port.ID,
