@@ -77,30 +77,22 @@ func TestPopulateCluster_Subnets(t *testing.T) {
 			ExpectedServiceClusterIPRange: "10.0.0.0/12",
 		},
 		{
-			NonMasqueradeCIDR:             "fd00:10:96::/96",
-			ExpectedClusterCIDR:           "fd00:10:96::8000:0/97",
-			ExpectedServiceClusterIPRange: "fd00:10:96::/108",
-		},
-		{
-			NonMasqueradeCIDR:             "fd00:10:96::/95",
-			ExpectedClusterCIDR:           "fd00:10:96::1:0:0/96",
-			ExpectedServiceClusterIPRange: "fd00:10:96::/108",
-		},
-		{
-			NonMasqueradeCIDR:             "fd00:10:96::/94",
-			ExpectedClusterCIDR:           "fd00:10:96::1:0:0/96",
-			ExpectedServiceClusterIPRange: "fd00:10:96::/108",
-		},
-		{
-			NonMasqueradeCIDR:             "fd00:10:96::/106",
-			ExpectedClusterCIDR:           "fd00:10:96::20:0/107",
-			ExpectedServiceClusterIPRange: "fd00:10:96::/109",
+			NonMasqueradeCIDR:             "::/0",
+			ExpectedServiceClusterIPRange: "fd00:5e4f:ce::/108",
 		},
 	}
 	for _, tc := range tests {
 		t.Run(tc.NonMasqueradeCIDR, func(t *testing.T) {
 			cloud, c := buildMinimalCluster()
 			c.Spec.NonMasqueradeCIDR = tc.NonMasqueradeCIDR
+			c.Spec.Networking.Kubenet = nil
+			c.Spec.Networking.CNI = &kopsapi.CNINetworkingSpec{}
+			c.Spec.ExternalCloudControllerManager = &kopsapi.CloudControllerManagerConfig{}
+			c.Spec.CloudConfig = &kopsapi.CloudConfiguration{
+				AWSEBSCSIDriver: &kopsapi.AWSEBSCSIDriver{
+					Enabled: fi.Bool(true),
+				},
+			}
 
 			err := PerformAssignments(c, cloud)
 			require.NoError(t, err, "PerformAssignments")
@@ -205,8 +197,8 @@ func build(c *kopsapi.Cluster) (*kopsapi.Cluster, error) {
 
 func TestPopulateCluster_Kubenet(t *testing.T) {
 	_, c := buildMinimalCluster()
-
 	c.Spec.ContainerRuntime = "docker"
+
 	full, err := build(c)
 	if err != nil {
 		t.Fatalf("error during build: %v", err)
