@@ -45,6 +45,7 @@ type Ocean struct {
 	MinSize                  *int64
 	MaxSize                  *int64
 	UtilizeReservedInstances *bool
+	UtilizeCommitments       *bool
 	FallbackToOnDemand       *bool
 	DrainingTimeout          *int64
 	GracePeriod              *int64
@@ -151,6 +152,7 @@ func (o *Ocean) Find(c *fi.Context) (*Ocean, error) {
 		if strategy := ocean.Strategy; strategy != nil {
 			actual.FallbackToOnDemand = strategy.FallbackToOnDemand
 			actual.UtilizeReservedInstances = strategy.UtilizeReservedInstances
+			actual.UtilizeCommitments = strategy.UtilizeCommitments
 
 			if strategy.DrainingTimeout != nil {
 				actual.DrainingTimeout = fi.Int64(int64(fi.IntValue(strategy.DrainingTimeout)))
@@ -339,7 +341,7 @@ func (s *Ocean) CheckChanges(a, e, changes *Ocean) error {
 }
 
 func (o *Ocean) RenderAWS(t *awsup.AWSAPITarget, a, e, changes *Ocean) error {
-	return o.createOrUpdate(t.Cloud.(awsup.AWSCloud), a, e, changes)
+	return o.createOrUpdate(t.Cloud, a, e, changes)
 }
 
 func (o *Ocean) createOrUpdate(cloud awsup.AWSCloud, a, e, changes *Ocean) error {
@@ -379,6 +381,7 @@ func (_ *Ocean) create(cloud awsup.AWSCloud, a, e, changes *Ocean) error {
 	{
 		ocean.Strategy.SetFallbackToOnDemand(e.FallbackToOnDemand)
 		ocean.Strategy.SetUtilizeReservedInstances(e.UtilizeReservedInstances)
+		ocean.Strategy.SetUtilizeCommitments(e.UtilizeCommitments)
 
 		if e.DrainingTimeout != nil {
 			ocean.Strategy.SetDrainingTimeout(fi.Int(int(*e.DrainingTimeout)))
@@ -619,6 +622,17 @@ func (_ *Ocean) update(cloud awsup.AWSCloud, a, e, changes *Ocean) error {
 			changed = true
 		}
 
+		// Utilize commitments.
+		if changes.UtilizeCommitments != nil {
+			if ocean.Strategy == nil {
+				ocean.Strategy = new(aws.Strategy)
+			}
+
+			ocean.Strategy.SetUtilizeCommitments(e.UtilizeCommitments)
+			changes.UtilizeCommitments = nil
+			changed = true
+		}
+
 		// Draining timeout.
 		if changes.DrainingTimeout != nil {
 			if ocean.Strategy == nil {
@@ -980,33 +994,34 @@ func (_ *Ocean) update(cloud awsup.AWSCloud, a, e, changes *Ocean) error {
 }
 
 type terraformOcean struct {
-	Name                   *string                    `json:"name,omitempty" cty:"name"`
-	ControllerClusterID    *string                    `json:"controller_id,omitempty" cty:"controller_id"`
-	Region                 *string                    `json:"region,omitempty" cty:"region"`
-	InstanceTypesWhitelist []string                   `json:"whitelist,omitempty" cty:"whitelist"`
-	InstanceTypesBlacklist []string                   `json:"blacklist,omitempty" cty:"blacklist"`
-	SubnetIDs              []*terraformWriter.Literal `json:"subnet_ids,omitempty" cty:"subnet_ids"`
-	AutoScaler             *terraformAutoScaler       `json:"autoscaler,omitempty" cty:"autoscaler"`
-	Tags                   []*terraformKV             `json:"tags,omitempty" cty:"tags"`
+	Name                   *string                    `cty:"name"`
+	ControllerClusterID    *string                    `cty:"controller_id"`
+	Region                 *string                    `cty:"region"`
+	InstanceTypesWhitelist []string                   `cty:"whitelist"`
+	InstanceTypesBlacklist []string                   `cty:"blacklist"`
+	SubnetIDs              []*terraformWriter.Literal `cty:"subnet_ids"`
+	AutoScaler             *terraformAutoScaler       `cty:"autoscaler"`
+	Tags                   []*terraformKV             `cty:"tags"`
 
-	MinSize         *int64 `json:"min_size,omitempty" cty:"min_size"`
-	MaxSize         *int64 `json:"max_size,omitempty" cty:"max_size"`
-	DesiredCapacity *int64 `json:"desired_capacity,omitempty" cty:"desired_capacity"`
+	MinSize         *int64 `cty:"min_size"`
+	MaxSize         *int64 `cty:"max_size"`
+	DesiredCapacity *int64 `cty:"desired_capacity"`
 
-	FallbackToOnDemand       *bool  `json:"fallback_to_ondemand,omitempty" cty:"fallback_to_ondemand"`
-	UtilizeReservedInstances *bool  `json:"utilize_reserved_instances,omitempty" cty:"utilize_reserved_instances"`
-	DrainingTimeout          *int64 `json:"draining_timeout,omitempty" cty:"draining_timeout"`
-	GracePeriod              *int64 `json:"grace_period,omitempty" cty:"grace_period"`
+	FallbackToOnDemand       *bool  `cty:"fallback_to_ondemand"`
+	UtilizeReservedInstances *bool  `cty:"utilize_reserved_instances"`
+	UtilizeCommitments       *bool  `cty:"utilize_commitments"`
+	DrainingTimeout          *int64 `cty:"draining_timeout"`
+	GracePeriod              *int64 `cty:"grace_period"`
 
-	Monitoring               *bool                      `json:"monitoring,omitempty" cty:"monitoring"`
-	EBSOptimized             *bool                      `json:"ebs_optimized,omitempty" cty:"ebs_optimized"`
-	ImageID                  *string                    `json:"image_id,omitempty" cty:"image_id"`
-	AssociatePublicIPAddress *bool                      `json:"associate_public_ip_address,omitempty" cty:"associate_public_ip_address"`
-	RootVolumeSize           *int64                     `json:"root_volume_size,omitempty" cty:"root_volume_size"`
-	UserData                 *terraformWriter.Literal   `json:"user_data,omitempty" cty:"user_data"`
-	IAMInstanceProfile       *terraformWriter.Literal   `json:"iam_instance_profile,omitempty" cty:"iam_instance_profile"`
-	KeyName                  *terraformWriter.Literal   `json:"key_name,omitempty" cty:"key_name"`
-	SecurityGroups           []*terraformWriter.Literal `json:"security_groups,omitempty" cty:"security_groups"`
+	Monitoring               *bool                      `cty:"monitoring"`
+	EBSOptimized             *bool                      `cty:"ebs_optimized"`
+	ImageID                  *string                    `cty:"image_id"`
+	AssociatePublicIPAddress *bool                      `cty:"associate_public_ip_address"`
+	RootVolumeSize           *int64                     `cty:"root_volume_size"`
+	UserData                 *terraformWriter.Literal   `cty:"user_data"`
+	IAMInstanceProfile       *terraformWriter.Literal   `cty:"iam_instance_profile"`
+	KeyName                  *terraformWriter.Literal   `cty:"key_name"`
+	SecurityGroups           []*terraformWriter.Literal `cty:"security_groups"`
 }
 
 func (_ *Ocean) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *Ocean) error {
@@ -1023,6 +1038,7 @@ func (_ *Ocean) RenderTerraform(t *terraform.TerraformTarget, a, e, changes *Oce
 
 		FallbackToOnDemand:       e.FallbackToOnDemand,
 		UtilizeReservedInstances: e.UtilizeReservedInstances,
+		UtilizeCommitments:       e.UtilizeCommitments,
 		DrainingTimeout:          e.DrainingTimeout,
 		GracePeriod:              e.GracePeriod,
 	}
